MemoryAdapter

Struct MemoryAdapter 

pub struct MemoryAdapter { /* private fields */ }
Async-safe in-memory adapter backed by shared state.

Implementations

Source

impl MemoryAdapter

pub fn new() -> MemoryAdapter

pub async fn records(&self, model: &str) -> Vec<IndexMap<String, DbValue>>

Return a snapshot of all records stored for a model.

pub async fn len(&self, model: &str) -> usize

Return the number of records stored for a model.

pub async fn is_empty(&self, model: &str) -> bool

Return true when no records are stored for a model.